import requests

import backoff

from core.store import get_api_hub_endpoint


class APIHubClient():
    api_hub__urlPath = '/shein/openapi/gsp/transmit'

    def __init__(self, store_id, store_name, target_url):
        self.store_id = store_id
        self.store_name = store_name
        self.headers = {
            'Content-Type': 'application/json',
            'X-store-id': self.store_id,
            'X-store-name': self.store_name,
            'X-target-url': target_url,
        }

    @property
    def api_hub__endpoint(self):
        endpoint = get_api_hub_endpoint(self.store_id, self.store_name)
        return endpoint

    def get(self, params=None, data=None):
        @backoff.on_exception(
            backoff.expo,
            requests.exceptions.RequestException,
            max_time=3,
            giveup=lambda e: e.response.status_code == 401,
        )
        def func(params, data):
            rsp = requests.get(url=self.api_hub__endpoint + self.api_hub__urlPath,
                               headers=self.headers,
                               params=params,
                               data=data)
            return rsp
        rsp = func(params, data)
        return rsp

    def post(self, params=None, payload=None):
        @backoff.on_exception(
            backoff.expo,
            requests.exceptions.RequestException,
            max_time=3,
            giveup=lambda e: e.response.status_code == 401,
        )
        def func(params, payload):
            rsp = requests.post(url=self.api_hub__endpoint + self.api_hub__urlPath,
                                headers=self.headers,
                                params=params,
                                json=payload)
            return rsp
        rsp = func(params, payload)
        return rsp
